@@ -150,14 +150,14 @@ class Point:
                 if status.is_client_error(response.status_code):
                     if status.is_not_found(response.status_code):
                         self._cache = status.HTTP_404_NOT_FOUND
-                        raise PointNotFound404(self._point_id.url)
+                        raise PointNotFound404(self._client.url)
                     if response.status_code == status.HTTP_429_TOO_MANY_REQUESTS:
-                        raise PointThrottled(self._point_id.url, response.status_code, response.headers.get(
+                        raise PointThrottled(self._client.url, response.status_code, response.headers.get(
                             'Retry-After'))
                     else:
-                        raise PointClientError(self._point_id.url, response.status_code, response.json())
+                        raise PointClientError(self._client.url, response.status_code, response.json())
                 else:
-                    raise PointServerError(self._point_id.url, response.status_code, response.text)
+                    raise PointServerError(self._client.url, response.status_code, response.text)
 
 
 class ObjectPoint(Point):
