@@ -50,10 +50,12 @@ class RussianIdentificationProcessReadContract(Contract):
     passport_number_old = serializers.CharField(max_length=6, allow_blank=True)
 
 
-viewsets = 'russian_identification_process'
-profiles_identification_russian_identification_process = ID(SERVICE, 'identification', viewsets)
+class RussianIdentificationProcessID(ID):
+    _service = SERVICE
+    _app = 'identification'
+    _view_set = 'russian_identification_process'
 
 
 class RussianIdentificationProcessPoint(ListPointMixin, ContractPoint):
-    _point_id = profiles_identification_russian_identification_process
+    _point_id = RussianIdentificationProcessID()
     _read_contract = RussianIdentificationProcessReadContract
