@@ -7,13 +7,15 @@ from expressmoney.api import *
 SERVICE = 'storage'
 
 
-class UserFileReadContract(Contract):
+class UploadFileResponseContract(Contract):
     alphanumeric = RegexValidator(r'^[0-9a-zA-Z_]*$', 'Only alphanumeric characters are allowed.')
-
-    id = serializers.IntegerField(min_value=1)
     name = serializers.CharField(max_length=64, validators=(alphanumeric,))
-    file = serializers.URLField()
+
+
+class UserFileReadContract(UploadFileResponseContract):
+    id = serializers.IntegerField(min_value=1)
     public_url = serializers.URLField(allow_null=True)
+    file = serializers.URLField()
 
 
 class UserFileID(ID):
@@ -35,6 +37,7 @@ class UserFilePoint(ListPointMixin, ContractPoint):
     _point = 'user_file'
 
 
-class UploadFilePoint(UploadFilePointMixin, ContractPoint):
+class UploadFilePoint(UploadFilePointMixin, ResponseMixin, ContractPoint):
     _point_id = UploadFileID()
+    _response_contract = UploadFileResponseContract
     _read_contract = None
